@@ -70,7 +70,7 @@ def _inside_quote(quotes: list, issues):
     return issues
 
 
-def qallback(instance, segment, metadata, language):
+def qallback(instance, segment, metadata, language, content):
     """
     Helper libs won't memoize this for us, because
     "Arguments to memoized function must be hashable"
@@ -93,6 +93,12 @@ def qallback(instance, segment, metadata, language):
         issues = instance.analyzer.analyze_with_metadata(
             segment, language=language, meta_value=meta_value, sub_groups=sub_groups
         )
+    elif _has_callable(instance.analyzer, 'analyze_with_full_payload'):
+        # meta_value not implemented in this method, as it is removed from payload
+        # TODO clean up meta_value code
+        issues = instance.analyzer.analyze_with_full_payload(
+            segment, language=language, sub_groups=sub_groups, meta=metadata, content=content
+        )
     else:
         issues = instance.analyzer.analyze(segment)
 
