@@ -89,7 +89,7 @@ async def get_root(self, request):
 
 async def add_start_time(request):
     """Prepend initial time when this request was served."""
-    request["start_time"] = time.time()
+    request.ctx.start_time = time.time()
 
 
 async def add_perf_stats(self, request, response):
@@ -103,7 +103,7 @@ async def add_perf_stats(self, request, response):
     is_check = request.path in ["/ready", "/healthy"]
     should_log = not (is_get or is_check)
     if should_log:
-        latency = round((time.time() - request["start_time"]) * 1000)
+        latency = round((time.time() - request.ctx.start_time) * 1000)
         n_seg, n_sent, n_word = get_payload_stats(request.json, self.validator.nlp)
         latency_sec = latency / 1000
 
