@@ -26,6 +26,8 @@ def get_strings_json(string_path=None):
         ["strings.json"],
         ["resources", "strings.json"],
         ["strings", "strings.json"],
+        ["conf", "strings.json"],
+        ["config", "strings.json"],
     ]
     STRING_FILE = None
     if string_path is None:
